# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class ExperimentAddTagAPIInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'all': 'bool',
        'excluded_experiment_numbers': 'list[int]',
        'experiment_numbers': 'list[int]',
        'tags': 'list[ProtoTag]'
    }

    attribute_map = {
        'all': 'all',
        'excluded_experiment_numbers': 'excluded_experiment_numbers',
        'experiment_numbers': 'experiment_numbers',
        'tags': 'tags'
    }

    def __init__(self, all=None, excluded_experiment_numbers=None, experiment_numbers=None, tags=None, local_vars_configuration=None):  # noqa: E501
        """ExperimentAddTagAPIInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._all = None
        self._excluded_experiment_numbers = None
        self._experiment_numbers = None
        self._tags = None
        self.discriminator = None

        if all is not None:
            self.all = all
        if excluded_experiment_numbers is not None:
            self.excluded_experiment_numbers = excluded_experiment_numbers
        if experiment_numbers is not None:
            self.experiment_numbers = experiment_numbers
        self.tags = tags

    @property
    def all(self):
        """Gets the all of this ExperimentAddTagAPIInput.  # noqa: E501


        :return: The all of this ExperimentAddTagAPIInput.  # noqa: E501
        :rtype: bool
        """
        return self._all

    @all.setter
    def all(self, all):
        """Sets the all of this ExperimentAddTagAPIInput.


        :param all: The all of this ExperimentAddTagAPIInput.  # noqa: E501
        :type all: bool
        """

        self._all = all

    @property
    def excluded_experiment_numbers(self):
        """Gets the excluded_experiment_numbers of this ExperimentAddTagAPIInput.  # noqa: E501


        :return: The excluded_experiment_numbers of this ExperimentAddTagAPIInput.  # noqa: E501
        :rtype: list[int]
        """
        return self._excluded_experiment_numbers

    @excluded_experiment_numbers.setter
    def excluded_experiment_numbers(self, excluded_experiment_numbers):
        """Sets the excluded_experiment_numbers of this ExperimentAddTagAPIInput.


        :param excluded_experiment_numbers: The excluded_experiment_numbers of this ExperimentAddTagAPIInput.  # noqa: E501
        :type excluded_experiment_numbers: list[int]
        """

        self._excluded_experiment_numbers = excluded_experiment_numbers

    @property
    def experiment_numbers(self):
        """Gets the experiment_numbers of this ExperimentAddTagAPIInput.  # noqa: E501


        :return: The experiment_numbers of this ExperimentAddTagAPIInput.  # noqa: E501
        :rtype: list[int]
        """
        return self._experiment_numbers

    @experiment_numbers.setter
    def experiment_numbers(self, experiment_numbers):
        """Sets the experiment_numbers of this ExperimentAddTagAPIInput.


        :param experiment_numbers: The experiment_numbers of this ExperimentAddTagAPIInput.  # noqa: E501
        :type experiment_numbers: list[int]
        """

        self._experiment_numbers = experiment_numbers

    @property
    def tags(self):
        """Gets the tags of this ExperimentAddTagAPIInput.  # noqa: E501


        :return: The tags of this ExperimentAddTagAPIInput.  # noqa: E501
        :rtype: list[ProtoTag]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this ExperimentAddTagAPIInput.


        :param tags: The tags of this ExperimentAddTagAPIInput.  # noqa: E501
        :type tags: list[ProtoTag]
        """
        if self.local_vars_configuration.client_side_validation and tags is None:  # noqa: E501
            raise ValueError("Invalid value for `tags`, must not be `None`")  # noqa: E501

        self._tags = tags

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExperimentAddTagAPIInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ExperimentAddTagAPIInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmPipelineStepSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'created_dt': 'datetime',
        'description': 'str',
        'edges': 'OrmPipelineStepSpecEdges',
        'id': 'int',
        'pipeline_spec_id': 'int',
        'spec': 'dict[str, object]',
        'step_key': 'str',
        'step_type': 'str',
        'title': 'str',
        'updated_dt': 'datetime'
    }

    attribute_map = {
        'created_dt': 'created_dt',
        'description': 'description',
        'edges': 'edges',
        'id': 'id',
        'pipeline_spec_id': 'pipeline_spec_id',
        'spec': 'spec',
        'step_key': 'step_key',
        'step_type': 'step_type',
        'title': 'title',
        'updated_dt': 'updated_dt'
    }

    def __init__(self, created_dt=None, description=None, edges=None, id=None, pipeline_spec_id=None, spec=None, step_key=None, step_type=None, title=None, updated_dt=None, local_vars_configuration=None):  # noqa: E501
        """OrmPipelineStepSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._created_dt = None
        self._description = None
        self._edges = None
        self._id = None
        self._pipeline_spec_id = None
        self._spec = None
        self._step_key = None
        self._step_type = None
        self._title = None
        self._updated_dt = None
        self.discriminator = None

        if created_dt is not None:
            self.created_dt = created_dt
        if description is not None:
            self.description = description
        if edges is not None:
            self.edges = edges
        if id is not None:
            self.id = id
        if pipeline_spec_id is not None:
            self.pipeline_spec_id = pipeline_spec_id
        if spec is not None:
            self.spec = spec
        if step_key is not None:
            self.step_key = step_key
        if step_type is not None:
            self.step_type = step_type
        if title is not None:
            self.title = title
        if updated_dt is not None:
            self.updated_dt = updated_dt

    @property
    def created_dt(self):
        """Gets the created_dt of this OrmPipelineStepSpec.  # noqa: E501


        :return: The created_dt of this OrmPipelineStepSpec.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this OrmPipelineStepSpec.


        :param created_dt: The created_dt of this OrmPipelineStepSpec.  # noqa: E501
        :type created_dt: datetime
        """

        self._created_dt = created_dt

    @property
    def description(self):
        """Gets the description of this OrmPipelineStepSpec.  # noqa: E501


        :return: The description of this OrmPipelineStepSpec.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this OrmPipelineStepSpec.


        :param description: The description of this OrmPipelineStepSpec.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def edges(self):
        """Gets the edges of this OrmPipelineStepSpec.  # noqa: E501


        :return: The edges of this OrmPipelineStepSpec.  # noqa: E501
        :rtype: OrmPipelineStepSpecEdges
        """
        return self._edges

    @edges.setter
    def edges(self, edges):
        """Sets the edges of this OrmPipelineStepSpec.


        :param edges: The edges of this OrmPipelineStepSpec.  # noqa: E501
        :type edges: OrmPipelineStepSpecEdges
        """

        self._edges = edges

    @property
    def id(self):
        """Gets the id of this OrmPipelineStepSpec.  # noqa: E501


        :return: The id of this OrmPipelineStepSpec.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OrmPipelineStepSpec.


        :param id: The id of this OrmPipelineStepSpec.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def pipeline_spec_id(self):
        """Gets the pipeline_spec_id of this OrmPipelineStepSpec.  # noqa: E501


        :return: The pipeline_spec_id of this OrmPipelineStepSpec.  # noqa: E501
        :rtype: int
        """
        return self._pipeline_spec_id

    @pipeline_spec_id.setter
    def pipeline_spec_id(self, pipeline_spec_id):
        """Sets the pipeline_spec_id of this OrmPipelineStepSpec.


        :param pipeline_spec_id: The pipeline_spec_id of this OrmPipelineStepSpec.  # noqa: E501
        :type pipeline_spec_id: int
        """

        self._pipeline_spec_id = pipeline_spec_id

    @property
    def spec(self):
        """Gets the spec of this OrmPipelineStepSpec.  # noqa: E501


        :return: The spec of this OrmPipelineStepSpec.  # noqa: E501
        :rtype: dict[str, object]
        """
        return self._spec

    @spec.setter
    def spec(self, spec):
        """Sets the spec of this OrmPipelineStepSpec.


        :param spec: The spec of this OrmPipelineStepSpec.  # noqa: E501
        :type spec: dict[str, object]
        """

        self._spec = spec

    @property
    def step_key(self):
        """Gets the step_key of this OrmPipelineStepSpec.  # noqa: E501


        :return: The step_key of this OrmPipelineStepSpec.  # noqa: E501
        :rtype: str
        """
        return self._step_key

    @step_key.setter
    def step_key(self, step_key):
        """Sets the step_key of this OrmPipelineStepSpec.


        :param step_key: The step_key of this OrmPipelineStepSpec.  # noqa: E501
        :type step_key: str
        """

        self._step_key = step_key

    @property
    def step_type(self):
        """Gets the step_type of this OrmPipelineStepSpec.  # noqa: E501


        :return: The step_type of this OrmPipelineStepSpec.  # noqa: E501
        :rtype: str
        """
        return self._step_type

    @step_type.setter
    def step_type(self, step_type):
        """Sets the step_type of this OrmPipelineStepSpec.


        :param step_type: The step_type of this OrmPipelineStepSpec.  # noqa: E501
        :type step_type: str
        """

        self._step_type = step_type

    @property
    def title(self):
        """Gets the title of this OrmPipelineStepSpec.  # noqa: E501


        :return: The title of this OrmPipelineStepSpec.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this OrmPipelineStepSpec.


        :param title: The title of this OrmPipelineStepSpec.  # noqa: E501
        :type title: str
        """

        self._title = title

    @property
    def updated_dt(self):
        """Gets the updated_dt of this OrmPipelineStepSpec.  # noqa: E501


        :return: The updated_dt of this OrmPipelineStepSpec.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this OrmPipelineStepSpec.


        :param updated_dt: The updated_dt of this OrmPipelineStepSpec.  # noqa: E501
        :type updated_dt: datetime
        """

        self._updated_dt = updated_dt

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmPipelineStepSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmPipelineStepSpec):
            return True

        return self.to_dict() != other.to_dict()
